@@ -1,6 +1,6 @@
 // rtplisten
 // Listen for RTP packets.
-// Copyright (C) 2001,2002,2003  Federico Montesino <fedemp@altern.org>
+// Copyright (C) 2001,2002,2003,2004 Federico Montesino <fedemp@altern.org>
 //  
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -27,11 +27,11 @@ using namespace std;
 class Listener: RTPSession {
 public:
 	Listener(InetMcastAddress& ima, tpport_t port):
-		RTPSocket(ima,port)
+		RTPSession(ima,port)
 	{ }
 
 	Listener(InetHostAddress& ia, tpport_t port):
-		RTPSocket(ia,port)
+		RTPSession(ia,port)
 	{ }
 
 	void listen()
@@ -48,9 +48,11 @@ public:
 		for (;;) {
 			const AppDataUnit* adu;
 			while ( (adu = getData(getFirstTimestamp())) ) {
-				cerr << "I got an app. data unit with "
+				cerr << "I got an app. data unit - "
 				     << adu->getSize()
-				     << " payload octets from "
+				     << " payload octets ("
+				     << "pt " << (int)adu->getType()
+				     << ") from "
 				     << hex << (int)adu->getSource().getID() 
 				     << "@" << dec <<
 					adu->getSource().getNetworkAddress()
@@ -103,7 +105,10 @@ public:
 		     << hex << (int)source.getID() << "@" 
 		     << dec
 		     << source.getNetworkAddress() << ":" 
-		     << source.getControlTransportPort() << endl;
+		     << source.getControlTransportPort()
+		     << " (" 
+		     << source.getParticipant()->getSDESItem(SDESItemTypeCNAME)
+		     << ") " << endl;
 		return result;
 	}
 	
